@@ -7,7 +7,7 @@
 # v. 2.0. If a copy of the MPL was not distributed with this file,You can
 # obtain one at http://mozilla.org/MPL/2.0/.
 
-from .schema import ModelSchema, PostLoadSchema  # noqa
+from .schema import SchemaWrapper, PostLoadSchema  # noqa
 from .exceptions import RegistryNotFound  # noqa
 from .fields import (  # noqa
     Nested, File, Text, JsonCollection, PhoneNumber, Country, InstanceField
