@@ -7,12 +7,12 @@
 # v. 2.0. If a copy of the MPL was not distributed with this file,You can
 # obtain one at http://mozilla.org/MPL/2.0/.
 from anyblok.tests.testcase import DBTestCase
-from anyblok_marshmallow import ModelSchema
+from anyblok_marshmallow import SchemaWrapper
 from anyblok_marshmallow import fields
 from anyblok import Declarations
 from anyblok.column import (
     Integer, LargeBinary, Selection, Json, String, Email, URL, UUID,
-    PhoneNumber, Country)
+    PhoneNumber, Country, Color)
 from anyblok.field import Function
 from os import urandom
 from base64 import b64encode
@@ -22,6 +22,12 @@ from uuid import uuid1
 from unittest import skipIf
 from sqlalchemy_utils import PhoneNumber as PN
 
+try:
+    import colour  # noqa
+    has_colour = True
+except Exception:
+    has_colour = False
+
 
 try:
     import furl  # noqa
@@ -84,7 +90,7 @@ class TestField(DBTestCase):
 
     def test_dump_function(self):
         registry = self.init_registry(self.add_field_function)
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
 
         exemple = registry.Exemple.insert()
@@ -103,7 +109,7 @@ class TestField(DBTestCase):
             'id': 1,
             'name': 'test',
         }
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
         data = exemple_schema.load(dump_data)
         self.assertEqual(data, dump_data)
@@ -114,14 +120,14 @@ class TestField(DBTestCase):
             'id': 1,
             'name': 'test',
         }
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
         errors = exemple_schema.validate(dump_data)
         self.assertFalse(errors)
 
     def test_dump_selection_with_object(self):
         registry = self.init_registry(self.add_field_selection_with_object)
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
 
         exemple = registry.Exemple.insert()
@@ -140,7 +146,7 @@ class TestField(DBTestCase):
             'id': 1,
             'name': 'foo',
         }
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
         data = exemple_schema.load(dump_data)
         self.assertEqual(data, dump_data)
@@ -151,7 +157,7 @@ class TestField(DBTestCase):
             'id': 1,
             'name': 'wrong_value',
         }
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
         with self.assertRaises(ValidationError) as exception:
             exemple_schema.load(dump_data)
@@ -167,7 +173,7 @@ class TestField(DBTestCase):
             'id': 1,
             'name': 'foo',
         }
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
         errors = exemple_schema.validate(dump_data)
         self.assertFalse(errors)
@@ -178,14 +184,14 @@ class TestField(DBTestCase):
             'id': 1,
             'name': 'wrong_value',
         }
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
         errors = exemple_schema.validate(dump_data)
         self.assertEqual(errors, {'name': ['Not a valid choice.']})
 
     def test_dump_selection_with_classmethod(self):
         registry = self.init_registry(self.add_field_selection_with_classmethod)
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
 
         exemple = registry.Exemple.insert()
@@ -204,7 +210,7 @@ class TestField(DBTestCase):
             'id': 1,
             'name': 'foo',
         }
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
         data = exemple_schema.load(dump_data)
         self.assertEqual(data, dump_data)
@@ -215,7 +221,7 @@ class TestField(DBTestCase):
             'id': 1,
             'name': 'wrong_value',
         }
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
 
         with self.assertRaises(ValidationError) as exception:
@@ -232,7 +238,7 @@ class TestField(DBTestCase):
             'id': 1,
             'name': 'foo',
         }
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
         errors = exemple_schema.validate(dump_data)
         self.assertFalse(errors)
@@ -243,19 +249,18 @@ class TestField(DBTestCase):
             'id': 1,
             'name': 'wrong_value',
         }
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
         errors = exemple_schema.validate(dump_data)
         self.assertEqual(errors, {'name': ['Not a valid choice.']})
 
     def getExempleSchemaLO(self):
 
-        class ExempleSchema(ModelSchema):
+        class ExempleSchema(SchemaWrapper):
+            model = 'Model.Exemple'
 
-            file = fields.File()
-
-            class Meta:
-                model = 'Model.Exemple'
+            class Schema:
+                file = fields.File()
 
         return ExempleSchema
 
@@ -333,11 +338,12 @@ class TestField(DBTestCase):
     @property
     def getJsonPropertySchema1(self):
 
-        class JsonCollectionSchema(ModelSchema):
-            class Meta:
-                model = 'Model.Exemple2'
+        class JsonCollectionSchema(SchemaWrapper):
+            model = 'Model.Exemple2'
 
-            name = fields.JsonCollection(fieldname="properties", keys=['name'])
+            class Schema:
+                name = fields.JsonCollection(
+                    fieldname="properties", keys=['name'])
 
         return JsonCollectionSchema
 
@@ -345,31 +351,32 @@ class TestField(DBTestCase):
         self.init_registry(self.add_field_json_collection_property)
 
         with self.assertRaises(ValueError):
-            class JsonCollectionSchema(ModelSchema):
-                class Meta:
-                    model = 'Model.Exemple2'
+            class JsonCollectionSchema(SchemaWrapper):
+                model = 'Model.Exemple2'
 
-                name = fields.JsonCollection(
-                    fieldname="properties",
-                    keys=['name'],
-                    cls_or_instance_type=String  # this is an AnyBlok String
-                                                 # not a marshmallow String
-                )
+                class Schema:
+                    name = fields.JsonCollection(
+                        fieldname="properties",
+                        keys=['name'],
+                        cls_or_instance_type=String  # this is an AnyBlok String
+                                                     # not a marshmallow String
+                    )
 
     def test_json_collection_wrong_field_instance_type(self):
         self.init_registry(self.add_field_json_collection_property)
 
         with self.assertRaises(ValueError):
-            class JsonCollectionSchema(ModelSchema):
-                class Meta:
-                    model = 'Model.Exemple2'
+            class JsonCollectionSchema(SchemaWrapper):
+                model = 'Model.Exemple2'
 
-                name = fields.JsonCollection(
-                    fieldname="properties",
-                    keys=['name'],
-                    cls_or_instance_type=String()  # this is an AnyBlok String
-                                                   # not a marshmallow String
-                )
+                class Schema:
+                    name = fields.JsonCollection(
+                        fieldname="properties",
+                        keys=['name'],
+                        cls_or_instance_type=String()
+                        # this is an AnyBlok String
+                        # not a marshmallow String
+                    )
 
     def test_dump_json_collection_list(self):
         registry = self.init_registry(self.add_field_json_collection_property)
@@ -411,15 +418,15 @@ class TestField(DBTestCase):
         exemple = registry.Exemple.insert(properties={'name': ['foo', 'bar']})
         exemple2 = registry.Exemple2.insert(name='foo')
 
-        class JsonCollectionSchema(ModelSchema):
-            class Meta:
-                model = 'Model.Exemple2'
+        class JsonCollectionSchema(SchemaWrapper):
+            model = 'Model.Exemple2'
 
-            name = fields.JsonCollection(
-                fieldname="properties",
-                keys=['name'],
-                cls_or_instance_type=fields.String(required=True)
-            )
+            class Schema:
+                name = fields.JsonCollection(
+                    fieldname="properties",
+                    keys=['name'],
+                    cls_or_instance_type=fields.String(required=True)
+                )
 
         exemple_schema = JsonCollectionSchema(registry=registry)
         data = exemple_schema.dump(
@@ -668,20 +675,20 @@ class TestField(DBTestCase):
                 'name': {'foo2': 'Foo 2', 'bar2': 'Bar 2'}}}})
         exemple3 = registry.Exemple3.insert(name1='foo', name2='foo2')
 
-        class JsonCollectionSchema(ModelSchema):
-            class Meta:
-                model = 'Model.Exemple3'
+        class JsonCollectionSchema(SchemaWrapper):
+            model = 'Model.Exemple3'
 
-            name1 = fields.JsonCollection(
-                fieldname="properties1",
-                keys=['sub', 'name'],
-                instance='theexemple1'
-            )
-            name2 = fields.JsonCollection(
-                fieldname="properties2",
-                keys=['sub', 'sub', 'name'],
-                instance='theexemple2'
-            )
+            class Schema:
+                name1 = fields.JsonCollection(
+                    fieldname="properties1",
+                    keys=['sub', 'name'],
+                    instance='theexemple1'
+                )
+                name2 = fields.JsonCollection(
+                    fieldname="properties2",
+                    keys=['sub', 'sub', 'name'],
+                    instance='theexemple2'
+                )
 
         exemple_schema = JsonCollectionSchema(registry=registry)
         errors = exemple_schema.validate(
@@ -721,20 +728,20 @@ class TestField(DBTestCase):
                 'name': {'foo2': 'Foo 2', 'bar2': 'Bar 2'}}}})
         exemple3 = registry.Exemple3.insert(name1='foo', name2='foo2')
 
-        class JsonCollectionSchema(ModelSchema):
-            class Meta:
-                model = 'Model.Exemple2'
+        class JsonCollectionSchema(SchemaWrapper):
+            model = 'Model.Exemple2'
 
-            name1 = fields.JsonCollection(
-                fieldname="properties",
-                keys=['sub', 'name'],
-                instance='exemple1'
-            )
-            name2 = fields.JsonCollection(
-                fieldname="properties",
-                keys=['sub', 'sub', 'name'],
-                instance='exemple2'
-            )
+            class Schema:
+                name1 = fields.JsonCollection(
+                    fieldname="properties",
+                    keys=['sub', 'name'],
+                    instance='exemple1'
+                )
+                name2 = fields.JsonCollection(
+                    fieldname="properties",
+                    keys=['sub', 'sub', 'name'],
+                    instance='exemple2'
+                )
 
         exemple_schema = JsonCollectionSchema(registry=registry)
         errors = exemple_schema.validate(
@@ -762,7 +769,7 @@ class TestField(DBTestCase):
 
     def test_email_field_type(self):
         registry = self.init_registry(self.add_field_email)
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
         self.assertTrue(
             isinstance(exemple_schema.schema.fields['email'], fields.Email))
@@ -770,7 +777,7 @@ class TestField(DBTestCase):
     def test_dump_email(self):
         registry = self.init_registry(self.add_field_email)
         exemple = registry.Exemple.insert(email='jssuzanne@anybox.fr')
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
         data = exemple_schema.dump(exemple)
         self.assertEqual(
@@ -783,7 +790,7 @@ class TestField(DBTestCase):
 
     def test_email_with_a_valid_email(self):
         registry = self.init_registry(self.add_field_email)
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
         dump_data = {
             'id': 1,
@@ -794,7 +801,7 @@ class TestField(DBTestCase):
 
     def test_email_with_an_invalid_email(self):
         registry = self.init_registry(self.add_field_email)
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
         dump_data = {
             'id': 1,
@@ -818,7 +825,7 @@ class TestField(DBTestCase):
     @skipIf(not has_furl, "furl is not installed")
     def test_url_field_type(self):
         registry = self.init_registry(self.add_field_url)
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
         self.assertTrue(
             isinstance(exemple_schema.schema.fields['url'], fields.URL))
@@ -827,7 +834,7 @@ class TestField(DBTestCase):
     def test_dump_url(self):
         registry = self.init_registry(self.add_field_url)
         exemple = registry.Exemple.insert(url='https://doc.anyblok.org')
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
         data = exemple_schema.dump(exemple)
         self.assertEqual(
@@ -841,7 +848,7 @@ class TestField(DBTestCase):
     @skipIf(not has_furl, "furl is not installed")
     def test_url_with_a_valid_url(self):
         registry = self.init_registry(self.add_field_url)
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
         dump_data = {
             'id': 1,
@@ -853,7 +860,7 @@ class TestField(DBTestCase):
     @skipIf(not has_furl, "furl is not installed")
     def test_url_with_an_invalid_url(self):
         registry = self.init_registry(self.add_field_url)
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
         dump_data = {
             'id': 1,
@@ -876,7 +883,7 @@ class TestField(DBTestCase):
 
     def test_uuid_field_type(self):
         registry = self.init_registry(self.add_field_uuid)
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
         self.assertTrue(
             isinstance(exemple_schema.schema.fields['uuid'], fields.UUID))
@@ -885,14 +892,14 @@ class TestField(DBTestCase):
         registry = self.init_registry(self.add_field_uuid)
         uuid = uuid1()
         exemple = registry.Exemple.insert(uuid=uuid)
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
         data = exemple_schema.dump(exemple)
         self.assertEqual(data, {'id': exemple.id, 'uuid': str(uuid)})
 
     def test_uuid_with_a_valid_uuid(self):
         registry = self.init_registry(self.add_field_uuid)
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
         uuid = uuid1()
         dump_data = {
@@ -904,7 +911,7 @@ class TestField(DBTestCase):
 
     def test_uuid_with_an_invalid_uuid(self):
         registry = self.init_registry(self.add_field_uuid)
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
         dump_data = {
             'id': 1,
@@ -928,7 +935,7 @@ class TestField(DBTestCase):
     @skipIf(not has_phonenumbers, "phonenumbers is not installed")
     def test_phonenumber_field_type(self):
         registry = self.init_registry(self.add_field_phonenumber)
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
         self.assertTrue(
             isinstance(exemple_schema.schema.fields['phonenumber'],
@@ -938,7 +945,7 @@ class TestField(DBTestCase):
     def test_dump_phonenumber(self):
         registry = self.init_registry(self.add_field_phonenumber)
         exemple = registry.Exemple.insert(phonenumber='+33953537297')
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
         data = exemple_schema.dump(exemple)
         self.assertEqual(
@@ -952,7 +959,7 @@ class TestField(DBTestCase):
     @skipIf(not has_phonenumbers, "phonenumbers is not installed")
     def test_phonenumber_with_a_valid_phonenumber(self):
         registry = self.init_registry(self.add_field_phonenumber)
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
         dump_data = {
             'id': 1,
@@ -965,7 +972,7 @@ class TestField(DBTestCase):
     @skipIf(not has_phonenumbers, "phonenumbers is not installed")
     def test_phonenumber_with_a_valid_phonenumber_and_other_region(self):
         registry = self.init_registry(self.add_field_phonenumber)
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry,
             context={'model': "Model.Exemple", "region": "GB"})
         dump_data = {
@@ -979,7 +986,7 @@ class TestField(DBTestCase):
     @skipIf(not has_phonenumbers, "phonenumbers is not installed")
     def test_phonenumber_with_an_international_valid_phonenumber(self):
         registry = self.init_registry(self.add_field_phonenumber)
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
         dump_data = {
             'id': 1,
@@ -992,7 +999,7 @@ class TestField(DBTestCase):
     @skipIf(not has_phonenumbers, "phonenumbers is not installed")
     def test_phonenumber_with_an_invalid_phonenumber(self):
         registry = self.init_registry(self.add_field_phonenumber)
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
         dump_data = {
             'id': 1,
@@ -1017,7 +1024,7 @@ class TestField(DBTestCase):
     @skipIf(not has_pycountry, "pycountry is not installed")
     def test_country_field_type(self):
         registry = self.init_registry(self.add_field_country)
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
         self.assertTrue(
             isinstance(exemple_schema.schema.fields['country'], fields.Country))
@@ -1027,7 +1034,7 @@ class TestField(DBTestCase):
         registry = self.init_registry(self.add_field_country)
         exemple = registry.Exemple.insert(
             country=pycountry.countries.get(alpha_2='FR'))
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
         data = exemple_schema.dump(exemple)
         self.assertEqual(
@@ -1041,7 +1048,7 @@ class TestField(DBTestCase):
     @skipIf(not has_pycountry, "pycountry is not installed")
     def test_country_with_a_valid_country(self):
         registry = self.init_registry(self.add_field_country)
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
         dump_data = {
             'id': 1,
@@ -1056,7 +1063,7 @@ class TestField(DBTestCase):
     @skipIf(not has_pycountry, "pycountry is not installed")
     def test_country_with_an_invalid_country(self):
         registry = self.init_registry(self.add_field_country)
-        exemple_schema = ModelSchema(
+        exemple_schema = SchemaWrapper(
             registry=registry, context={'model': "Model.Exemple"})
         dump_data = {
             'id': 1,
@@ -1408,3 +1415,49 @@ class TestField(DBTestCase):
             exception.exception.messages.get('number')[0][0],
             "Not a valid integer."
         )
+
+    def add_field_color(self):
+
+        @Declarations.register(Declarations.Model)
+        class Exemple:
+            id = Integer(primary_key=True)
+            color = Color()
+
+    @skipIf(not has_colour, "colour is not installed")
+    def test_colour_field_type(self):
+        registry = self.init_registry(self.add_field_color)
+        exemple_schema = SchemaWrapper(
+            registry=registry, context={'model': "Model.Exemple"})
+        self.assertTrue(
+            isinstance(exemple_schema.schema.fields['color'], fields.Color))
+
+    @skipIf(not has_colour, "colour is not installed")
+    def test_dump_colour(self):
+        registry = self.init_registry(self.add_field_color)
+        exemple = registry.Exemple.insert(color=colour.Color('#F5F5F5'))
+        self.assertEqual(exemple.color.hex, '#f5f5f5')
+        exemple_schema = SchemaWrapper(
+            registry=registry, context={'model': "Model.Exemple"})
+        data = exemple_schema.dump(exemple)
+        self.assertEqual(
+            data,
+            {
+                'id': exemple.id,
+                'color': "#f5f5f5",
+            }
+        )
+
+    @skipIf(not has_colour, "colour is not installed")
+    def test_colour_with_a_valid_color(self):
+        registry = self.init_registry(self.add_field_color)
+        exemple_schema = SchemaWrapper(
+            registry=registry, context={'model': "Model.Exemple"})
+        dump_data = {
+            'id': 1,
+            'color': "#F5F5F5",
+        }
+        load_data = exemple_schema.load(dump_data)
+        self.assertEqual(
+            load_data,
+            {'id': 1, 'color': colour.Color('#F5F5F5')}
+        )
