@@ -7,7 +7,7 @@
 # obtain one at http://mozilla.org/MPL/2.0/.
 from anyblok.tests.testcase import DBTestCase
 from . import add_complexe_model, CustomerSchema, AddressSchema, TagSchema
-from anyblok_marshmallow import ModelSchema
+from anyblok_marshmallow import SchemaWrapper
 from marshmallow import fields
 
 
@@ -104,16 +104,15 @@ class TestPrimaryKey(DBTestCase):
         registry = self.init_registry(add_complexe_model)
         self.registry = registry
 
-        class CustomerSchema(ModelSchema):
+        class CustomerSchema(SchemaWrapper):
+            model = 'Model.Customer'
+            registry = self.registry
+            only_primary_key = True
 
-            addresses = fields.Nested(
-                AddressSchema, many=True, exclude=('customer', ))
-            tags = fields.Nested(TagSchema, many=True)
-
-            class Meta:
-                model = 'Model.Customer'
-                registry = self.registry
-                only_primary_key = True
+            class Schema:
+                addresses = fields.Nested(
+                    AddressSchema, many=True, exclude=('customer', ))
+                tags = fields.Nested(TagSchema, many=True)
 
         customer_schema = CustomerSchema()
         tag = registry.Tag.insert(name="tag 1")
@@ -129,16 +128,15 @@ class TestPrimaryKey(DBTestCase):
         registry = self.init_registry(add_complexe_model)
         self.registry = registry
 
-        class CustomerSchema(ModelSchema):
+        class CustomerSchema(SchemaWrapper):
+            model = 'Model.Customer'
+            registry = self.registry
+            only_primary_key = True
 
-            addresses = fields.Nested(
-                AddressSchema, many=True, exclude=('customer', ))
-            tags = fields.Nested(TagSchema, many=True)
-
-            class Meta:
-                model = 'Model.Customer'
-                registry = self.registry
-                only_primary_key = True
+            class Schema:
+                addresses = fields.Nested(
+                    AddressSchema, many=True, exclude=('customer', ))
+                tags = fields.Nested(TagSchema, many=True)
 
         dump_data = {'id': 1}
         customer_schema = CustomerSchema()
@@ -149,16 +147,15 @@ class TestPrimaryKey(DBTestCase):
         registry = self.init_registry(add_complexe_model)
         self.registry = registry
 
-        class CustomerSchema(ModelSchema):
+        class CustomerSchema(SchemaWrapper):
+            model = 'Model.Customer'
+            registry = self.registry
+            only_primary_key = True
 
-            addresses = fields.Nested(
-                AddressSchema, many=True, exclude=('customer', ))
-            tags = fields.Nested(TagSchema, many=True)
-
-            class Meta:
-                model = 'Model.Customer'
-                registry = self.registry
-                only_primary_key = True
+            class Schema:
+                addresses = fields.Nested(
+                    AddressSchema, many=True, exclude=('customer', ))
+                tags = fields.Nested(TagSchema, many=True)
 
         dump_data = {'id': 1}
         customer_schema = CustomerSchema()
